# Beamer/LaTeX theme for kenotom presentations

This theme is based on the look and feel of the official Kenotom's PowerPoint(TM) template and enables the user to create professional presentations, having the advantages of the high-quality typesetting system of LaTeX, with an easy to use interface, provided by the theme style file.

This repo contains:
- A style file(.sty), to use it as beamer theme. This theme has various options to fine-tune the final look of the presentation.
- An `img` directory, containing all the graphic files used by the theme AND the source .svg files of each one of them.
- A template file to kick start a presentation very quickly
- A demo directory with a presentation, presenting this theme.


# System requirements

In order to use (and benefit) from this presentation theme you need:
1. A working `LaTeX` system
2. A working `git` version control system


## 1. Installing LaTeX
LaTeX is free software under the terms of the LaTeX Project Public License (LPPL). LaTeX is distributed through CTAN servers or comes as part of many easily installable and usable TeX distributions provided by the TeX User Group (TUG) or third parties. The supported operating systems are:

- **Linux**.: Almost all of the linux distributions offer LaTeX with Tex-Live being the most widespreaded
- **Mac OS**: With the [MacTex](https://www.tug.org/mactex/) as the provided LaTeX distribution
- **Windows**: With both [MikTeX](https://miktex.org/) and [TeX Live](https://www.tug.org/texlive/) as available distributions.

### **Note for Kenotom windows laptops**
We suggest the use of the portable version of the TeX Live distribution, installed on the user's directory, in order to avoid the need of admin rights.

More information about installing LaTeX you can find on [LaTeX project site](https://www.latex-project.org/get/)

## 2. Installing git
Before you start using Git, you have to make it available on your computer. Even if it’s already installed, it’s probably a good idea to update to the latest version. Git is available on Linux, MacOS and Windows.

### **Note for Kenotom windows laptops**
We suggest the use of the portable version of the git that can be found [here](https://git-scm.com/download/win), installed on the user's directory, in order to avoid the need of admin rights.

## Note about online editors
As you may know, there are online platforms like [overleaf](https://www.overleaf.com/) for example, providing LaTeX functionality. We strongly recommend to **avoid using them**. This is because, for using them, you will need to upload presentation related files online and this probably will be in conflict with Kenotom's security and privacy policy.

# Theme installation

There are various ways to get and use this theme.

## 1. Home installation

You can install the theme in the user's default TeX directory. This way you can use it as many times as you want, without the need of copying the theme files around, every time you need a new presentation. This repo does not include the `.ins` and `.dxi` files for installation. In contrary provides directly the theme's "ready-to-use" directory with the .sty file. The only thing to do is to place it in the LaTeX's default directory. Based on your OS, distribution and configuration this directory can vary. Fortunately LaTeX also looks for user packages in the user's home directory. Based on the OS these directories usually are located on:

| OS            |      Path    |
|---------------|--------------|
| Win10 texLive | $TEXMFHOME\tex\latex\local\ |
| Win10 MikTeX  | C:\Users\<user name>\Appdata\Local\MikTex\<number>\tex\latex\local\ |
| Linux         | ~/texmf/tex/latex/local/ |
| MacOS         | ~/Library/texmf/tex/latex/local/ |

So, when on the above directory, just clone this repository:

```
cd $TEXMFHOME\tex\latex\local\ 
git clone ssh://git@gitlab.kenotom.local/Ken-Lib/Documentation/beamerThemeKenotom.git
```

## 2. Local installation

Another option is to install the theme as system-wide package. The solution is pretty much the same as the above, with a couple of additions:
1. We need admin rights
2. We need to "tell" LaTeX to update it's cache, in order to find our theme.

If you really want to do it like that, you can start by looking [here](https://en.wikibooks.org/wiki/LaTeX/Installing_Extra_Packages)

## 3. Use the repo "in-place" (as git sub-module)

Additionally, you can `just` use this theme inside of your presentation directory. For example:
```
cd MyPresentation
git clone ssh://git@gitlab.kenotom.local/Ken-Lib/Documentation/beamerThemeKenotom.git
```
Of course, you can have a git repo for your presentation also. If so, you can add the theme as submodule:
```
git submodule add ssh://git@gitlab.kenotom.local/Ken-Lib/Documentation/beamerThemeKenotom.git beamerThemeKenotom
```

# How to use the theme
Using this theme, does not differ from any other beamer theme. Practically we need something like:

```Latex
\documentclass[12pt,aspectratio=169]{beamer}
\usetheme{Kenotom}

\title{Presentation title}
\subtitle{Subtitle (if there's one)}
\author{Your name}
\institute{Kenotom}
\date{\today}

\newcommand{\AuthorEmail}{user@kenotom.com}
\newcommand{\Address}{Eth. Antistasis 16 GR-55133, Thessaloniki - Greece}
\newcommand{\Telephone}{+30 2310 315470}

\begin{document}

\maketitle

\begin{frame}
	Hello world!
\end{frame}

\end{document}
```

## Kenotom environments

This theme provides some Kenotom specific commands and environments.

### \BeginCountingFrames
Use this inside your document before the frame you want to have the number "1". This command also enables the display of frame numbers at the bottom right of the frame here after.

### \OutlineFrame

Syntax:
```
\OutlineFrame[nosubsection]{<arg 1>}{<arg 2>}
```
Use this command to insert an outline frame. This command has two arguments and one option.
- nosubsection: Pass this option to disable the subsections in the outline
- <arg 1>: Title text to display in Grey color
- <arg 2>: Title text to display in Green color
The arguments are printed the one after the other.

### \BackFrame
Use this as last command inside your document, to insert a "Thank You" last frame.

### tickmarks environment
Use it like any other `itemize` or `enumerate` environment, in order to create lists with the green Kenotom tickmark for bullet icon.

### bullets environment
Use it like any other `itemize` or `enumerate` environment, in order to create lists with the green Kenotom vertical for bullet icon.


## Theme options

This theme provides some extra options, to fine-tune the final look. The options are passed normally inside the `[]` brackets in the `\usetheme` command. The options are:

### theme
You can pass `theme=value` and alter the theme look, or omit it to stay with the default. The available themes are:
- **light**: The official color theme, of the PowerPoint template
- **classic(default)**: A more dark font color variation of the official theme. This is better for engineering and math content.
- **dark**: A dark theme variation with dark backgroung and some color inversions.

### bouckground
You can pass `background=value` and alter the theme look, or omit it to stay with the default. The available themes are:
- **none(default)**: The official empty background for non-structure framer, of the PowerPoint template.
- **ribbon**: A more fancy background variation of the official theme, where we use the ribbon as background in all frames.

### title
You can pass `title=value` and alter the frame title size, or omit it to stay with the default. The available themes are:
- **normal(default)**: What we consider as normal size for a title. This size is smaller than the official, but suits better for slides with lot of engeneering content.
- **small**: An even more smaller title, for even more content heavy slides.
- **large**: The official title size

### nonavigation
You can pass it to disable the navigation bar at the bottom right.

### fancy
You can pass this option to enable fancy presentation. This means:
- The title frame becomes this fancy "Car pictured frame" from the official presentation
- The outline frame also becomes more fancy to look also like the official
- On each section there is an automatic insertion of fancy section frames like the official presentation.

If you omit this option, the presentation deviates a lot from the official, but becomes smaller and less "advertisement-like"

# Contributions
Any MR request with fixes and additions are welcome!

# Disclaimer

This theme is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

The official kenotom's approach for company presentations, IS the Microsoft's PowerPoint(TM) template. The work presented here, is entirely my own initiative and completely based on my personal preference in favor of LaTeX over the competition. Also, the visual result of a presentation based on this theme, in no way claims to be authentic. On the contrary, it is an approximation of the official version and in fact deliberately deviates from it, in many ways.

ALthough, as this theme is based on the official Kenotom's PowerPoint(TM) template, extensively uses parts of it. More precisely, it uses Kenotom's logos, colors and the look and feel in general. Thus, ANY USE of the current theme, outside the Kenotom's activities, network and/or personal computers, IS STRICTLY FORBIDDEN.
